;* --------------------------------------------------------------------------------------
;*  Ted Salazar    (^_^)
;* --------------------------------------------------------------------------------------
;*  Filename:      main_6960.asm
;*  Date:          September 23, 2005
;*  Version:       1.00
;*
;*  Description:   Main assembly source file for the AppNote titled,
;*                 "Using the MAXQ2000 with the MAX6960 to create a
;*                  stock quote display"
;* --------------------------------------------------------------------------------------
;*  Dev Tools:     MAX-IDE Version 1.0 
;*
;*  Hardware:      MAX6960EVKIT
;*                 MAXQ2000-KIT
;*
;*  Hardware Setup:MAX6960VKIT: All jumpers in default locations
;*                               See the MAX6960EVKIT Data Sheet  
;*                 MAXQ2000-KIT: All jumpers in default locations
;*                               See the MAXQ2000-KIT Data Sheet
;*                  All dip switches set as follows:
;*                  SW1.1 OFF  
;*                  SW1.2 OFF  
;*                  SW1.3 OFF  
;*                  SW1.4 ON 
;*                  SW1.5 OFF
;*                  SW1.6 OFF 
;*                  SW1.7 ON 
;*                  SW1.8 OFF 
;*
;*                  SW3.1 OFF 
;*                  SW3.2 OFF 
;*                  SW3.3 OFF 
;*                  SW3.4 OFF 
;*                  SW3.5 OFF
;*                  SW3.6 OFF 
;*                  SW3.7 OFF 
;*                  SW3.8 OFF 
;*
;*                  SW6.1 OFF 
;*                  SW6.2 OFF 
;*                  SW6.3 OFF 
;*                  SW6.4 OFF 
;*                  SW6.5 OFF 
;*                  SW6.6 OFF
;*                  SW6.7 OFF 
;*                  SW6.8 OFF 
;*
;* --------------------------------------------------------------------------------------

$include (maxQ2000.inc)
$include (maxq2000_6960.inc)
$include (max6960_spi.inc)
$include (serial_IO_6960.inc)

;
; Define the soft stack for interrupt storage at 200h
;
SOFTSTACK_W EQU 200h

org 0
;*****************************************************
; MAXQ INITIALIZATION
;******************************************************
;*  General MAXQ2000 Initialization
    call general_initialization         
;*  Configure the Serial Port for 8-N-1 @ 19.2k
    call MAXQ_serial_port_init_8_N_1_19_2k
;*  Configure the SPI Peripheral for CPOL CPHA 0,0
	call 	SPI_Conf_00

;*****************************************************
; MAX6960 INITIALIZATION
;*****************************************************
;*  Initialize the RESET   
    move    PO5.3, #1           ; RESET high.
    call Delay_2_and_a_half_ms

;*  Initialize the MAX6960 RESET   
    move    PO5.3, #0           ; RESET low.
    call Delay_2_and_a_half_ms


;*  Initialize the RESET   
    move    PO5.3, #1           ; RESET high.
    call Delay_50ms
    call Delay_50ms

;*  Initialize the MAX6960    
    move    PO5.4, #0           ; Set /CS low.
;*	Panel Configuration Register
	move	ACC,   #0Dh			; Reg 0x0D
    call    spi_transmit
	move	ACC,   #41h			; Reg 0x0D Data 0x41
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.

;*	Panel Intensity Register
    move    PO5.4, #0           ; Set /CS low.
	move	ACC,   #02h			; Reg 0x02
    call    spi_transmit
	move	ACC,   #0030h		; Reg 0x02 Data 0x30
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.

;
;*	Number of Cascaded Devices Register
    move    PO5.4, #0           ; Set /CS low.
	move	ACC,   #0Eh			; Reg 0x0E
    call    spi_transmit
	move	ACC,   #13h			; Reg 0x0E Data 0x13 (5 EVkits)
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.
;   
;*	Number of Display Rows Register
    move    PO5.4, #0           ; Set /CS low.
	move	ACC,   #0Fh			; Reg 0x0F
    call    spi_transmit
	move	ACC,   #01h			; Reg 0x0F Data 0x01
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.

;
;*  Required Long 450ms Delay After MAX6960 Configuration
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms
    call Delay_50ms


; 24-bit addressing mode D23-D0
;*************************************************
;* One Green Dot Alive Indicator
;*************************************************
;*  Byte1 starts @ Addr 0xA0 and ends @ Addr 0xA7    

;*  1st 24-bit operation
    move    PO5.4, #0           ; Set /CS low.
;*	D23-D16
	move	ACC,   #00h			; Write Mode, Plane 0
    call    spi_transmit
;*  D15-D8
	move	ACC,   #00A0h			; Addr 0xA0
    call    spi_transmit
;*  D7-D0
	move	ACC,   #0008h			; Data 0x08
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.
;*************************************************

;*************************************************
;* Serial COM Port Communications
;*************************************************
;  XXXU321.12X
;  X = ignore
;  X = ignore
;  X = ignore
;  U = up/down byte
;  3 = hundreds
;  2 = tens
;  1 = ones
;  1 = tenths
;  2 = hundreths
;  X = ignore
RX_Loop:
; Ignore the 1st received char
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[3], A[2]	  	; For Testing Only

; Ignore the 2nd received char 
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[4], A[2]	  	; For Testing Only

; Ignore the 3rd received char 
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[5], A[2]	  ; For Testing Only

; Ignore the 4th received char Ignore for now...Up_Down
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[6], A[2]	  

; The 5th received char Ignore for now...the Hundreds Digit
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[7], A[2]	 

; The 6th received char...the tens Digit
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[8], A[2]	 

; The 7th received char...the Ones Digit
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[9], A[2]	 

; The 8th received char...the Tenths Digit
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[10], A[2]	 

; The 9th received char...the Hundeths Digit
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[11], A[2]	 

; The 10th received char...Ignore and throw away
	move A[0], #PORT_0
	call serial_receivedata		; Receives a char 
	move ACC, A[2]	
    move A[12], A[2]	 

;*	Clear Planes Register 0x0C
;   Clearing Only Plane 0: Red and Green
    move    PO5.4, #0           ; Set /CS low.
	move	ACC,   #0Ch			; Reg 0x0C
    call    spi_transmit
	move	ACC,   #11h			; Data 0x01
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.

StockDown:                    ; StockUp = 0x00 = decimal 0
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]
    jump NZ, StockNoChange
    call RedStockDown
    jump Stock_Direction_Done
StockNoChange:                ; StockNoChange = 0x01 = decimal 1
    move	ACC,   #0001h		    
    sub A[6] ; ACC - A[6]
    jump NZ, StockUp
    call GrnStockNoChange
    jump Stock_Direction_Done
StockUp:                      ; StockUp = 0x02 = decimal 2           
    call GrnStockUp
Stock_Direction_Done:

Hundreds_Digit0:
    move	ACC,   #0000h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit1
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D0
    call RedHundredsDigitBlank  
    jump Hundreds_Digit_Done
G_100_D0:
    call GrnHundredsDigitBlank
    jump Hundreds_Digit_Done
Hundreds_Digit1:
    move	ACC,   #0001h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit2
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D0
    call RedHundredsDigit1  
    jump Hundreds_Digit_Done
G_100_D1:
    call GrnHundredsDigit1
    jump Hundreds_Digit_Done
Hundreds_Digit2:
    move	ACC,   #0002h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit3
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D2
    call RedHundredsDigit2  
    jump Hundreds_Digit_Done
G_100_D2:
    call GrnHundredsDigit2
    jump Hundreds_Digit_Done
Hundreds_Digit3:
    move	ACC,   #0003h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit4
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D3
    call RedHundredsDigit3
    jump Hundreds_Digit_Done
G_100_D3:
    call GrnHundredsDigit3
    jump Hundreds_Digit_Done
Hundreds_Digit4:
    move	ACC,   #0004h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit5
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D4
    call RedHundredsDigit4  
    jump Hundreds_Digit_Done
G_100_D4:
    call GrnHundredsDigit4
    jump Hundreds_Digit_Done
Hundreds_Digit5:
    move	ACC,   #0005h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit6
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D5
    call RedHundredsDigit5  
    jump Hundreds_Digit_Done
G_100_D5:
    call GrnHundredsDigit5
    jump Hundreds_Digit_Done
Hundreds_Digit6:
    move	ACC,   #0006h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit7
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D6
    call RedHundredsDigit6  
    jump Hundreds_Digit_Done
G_100_D6:
    call GrnHundredsDigit6
    jump Hundreds_Digit_Done
Hundreds_Digit7:
    move	ACC,   #0007h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit8
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D7
    call RedHundredsDigit7  
    jump Hundreds_Digit_Done
G_100_D7:
    call GrnHundredsDigit7
    jump Hundreds_Digit_Done
Hundreds_Digit8:
    move	ACC,   #0008h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit9
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D8
    call RedHundredsDigit8  
    jump Hundreds_Digit_Done
G_100_D8:
    call GrnHundredsDigit8
    jump Hundreds_Digit_Done
Hundreds_Digit9:
    move	ACC,   #0009h		    
    sub A[7] ; ACC - A[7]
    jump NZ, Hundreds_Digit?
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D9
    call RedHundredsDigit9  
    jump Hundreds_Digit_Done
G_100_D9:
    call GrnHundredsDigit9
    jump Hundreds_Digit_Done
Hundreds_Digit?:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100_D?
    call RedHundredsDigit?  
    jump Hundreds_Digit_Done
G_100_D?:
    call GrnHundredsDigit?
Hundreds_Digit_Done:


Tens_Digit0:
    move	ACC,   #0000h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit1
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D0
    call RedTensDigit0  
    jump Tens_Digit_Done
G_10_D0:
    call GrnTensDigit0
    jump Tens_Digit_Done
Tens_Digit1:
    move	ACC,   #0001h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit2
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D1
    call RedTensDigit1  
    jump Tens_Digit_Done
G_10_D1:
    call GrnTensDigit1
    jump Tens_Digit_Done
Tens_Digit2:
    move	ACC,   #0002h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit3
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D2
    call RedTensDigit2  
    jump Tens_Digit_Done
G_10_D2:
    call GrnTensDigit2
    jump Tens_Digit_Done
Tens_Digit3:
    move	ACC,   #0003h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit4
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D3
    call RedTensDigit3  
    jump Tens_Digit_Done
G_10_D3:
    call GrnTensDigit3
    jump Tens_Digit_Done
Tens_Digit4:
    move	ACC,   #0004h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit5
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D4
    call RedTensDigit4  
    jump Tens_Digit_Done
G_10_D4:
    call GrnTensDigit4
    jump Tens_Digit_Done
Tens_Digit5:
    move	ACC,   #0005h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit6
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D5
    call RedTensDigit5  
    jump Tens_Digit_Done
G_10_D5:
    call GrnTensDigit5
    jump Tens_Digit_Done
Tens_Digit6:
    move	ACC,   #0006h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit7
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D6
    call RedTensDigit6  
    jump Tens_Digit_Done
G_10_D6:
    call GrnTensDigit6
    jump Tens_Digit_Done
Tens_Digit7:
    move	ACC,   #0007h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit8
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D7
    call RedTensDigit7  
    jump Tens_Digit_Done
G_10_D7:
    call GrnTensDigit7
    jump Tens_Digit_Done
Tens_Digit8:
    move	ACC,   #0008h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit9
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D8
    call RedTensDigit8  
    jump Tens_Digit_Done
G_10_D8:
    call GrnTensDigit8
    jump Tens_Digit_Done
Tens_Digit9:
    move	ACC,   #0009h		    
    sub A[8] ; ACC - A[8]
    jump NZ, Tens_Digit?
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D9
    call RedTensDigit9  
    jump Tens_Digit_Done
G_10_D9:
    call GrnTensDigit9
    jump Tens_Digit_Done
Tens_Digit?:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10_D?
    call RedTensDigit?  
    jump Tens_Digit_Done
G_10_D?:
    call GrnTensDigit?
Tens_Digit_Done:

Ones_Digit0:
    move	ACC,   #0000h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit1
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D0
    call RedOnesDigit0  
    jump Ones_Digit_Done
G_1_D0:
    call GrnOnesDigit0
    jump Ones_Digit_Done
Ones_Digit1:
    move	ACC,   #0001h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit2
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D1
    call RedOnesDigit1  
    jump Ones_Digit_Done
G_1_D1:
    call GrnOnesDigit1
    jump Ones_Digit_Done
Ones_Digit2:
    move	ACC,   #0002h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit3
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D2
    call RedOnesDigit2  
    jump Ones_Digit_Done
G_1_D2:
    call GrnOnesDigit2
    jump Ones_Digit_Done
Ones_Digit3:
    move	ACC,   #0003h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit4
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D3
    call RedOnesDigit3  
    jump Ones_Digit_Done
G_1_D3:
    call GrnOnesDigit3
    jump Ones_Digit_Done
Ones_Digit4:
    move	ACC,   #0004h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit5
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D4
    call RedOnesDigit4  
    jump Ones_Digit_Done
G_1_D4:
    call GrnOnesDigit4
    jump Ones_Digit_Done
Ones_Digit5:
    move	ACC,   #0005h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit6
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D5
    call RedOnesDigit5  
    jump Ones_Digit_Done
G_1_D5:
    call GrnOnesDigit5
    jump Ones_Digit_Done
Ones_Digit6:
    move	ACC,   #0006h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit7
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D6
    call RedOnesDigit6  
    jump Ones_Digit_Done
G_1_D6:
    call GrnOnesDigit6
    jump Ones_Digit_Done
Ones_Digit7:
    move	ACC,   #0007h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit8
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D7
    call RedOnesDigit7  
    jump Ones_Digit_Done
G_1_D7:
    call GrnOnesDigit7
    jump Ones_Digit_Done
Ones_Digit8:
    move	ACC,   #0008h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit9
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D8
    call RedOnesDigit8  
    jump Ones_Digit_Done
G_1_D8:
    call GrnOnesDigit8
    jump Ones_Digit_Done
Ones_Digit9:
    move	ACC,   #0009h		    
    sub A[9] ; ACC - A[9]
    jump NZ, Ones_Digit?
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D9
    call RedOnesDigit9  
    jump Ones_Digit_Done
G_1_D9:
    call GrnOnesDigit9
    jump Ones_Digit_Done
Ones_Digit?:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_1_D?
    call RedOnesDigit?  
    jump Ones_Digit_Done
G_1_D?:
    call GrnOnesDigit?
Ones_Digit_Done:

Tenths_Digit0:
    move	ACC,   #0000h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit1
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D0
    call RedTenthsDigit0
    jump Tenths_Digit_Done
G_10th_D0:
    call GrnTenthsDigit0
    jump Tenths_Digit_Done
Tenths_Digit1:
    move	ACC,   #0001h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit2
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D1
    call RedTenthsDigit1
    jump Tenths_Digit_Done
G_10th_D1:
    call GrnTenthsDigit1
    jump Tenths_Digit_Done
Tenths_Digit2:
    move	ACC,   #0002h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit3
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D2
    call RedTenthsDigit2
    jump Tenths_Digit_Done
G_10th_D2:
    call GrnTenthsDigit2
    jump Tenths_Digit_Done
Tenths_Digit3:
    move	ACC,   #0003h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit4
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D3
    call RedTenthsDigit3
    jump Tenths_Digit_Done
G_10th_D3:
    call GrnTenthsDigit3
    jump Tenths_Digit_Done
Tenths_Digit4:
    move	ACC,   #0004h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit5
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D4
    call RedTenthsDigit4
    jump Tenths_Digit_Done
G_10th_D4:
    call GrnTenthsDigit4
    jump Tenths_Digit_Done
Tenths_Digit5:
    move	ACC,   #0005h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit6
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D5
    call RedTenthsDigit5
    jump Tenths_Digit_Done
G_10th_D5:
    call GrnTenthsDigit5
    jump Tenths_Digit_Done
Tenths_Digit6:
    move	ACC,   #0006h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit7
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D6
    call RedTenthsDigit6
    jump Tenths_Digit_Done
G_10th_D6:
    call GrnTenthsDigit6
    jump Tenths_Digit_Done
Tenths_Digit7:
    move	ACC,   #0007h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit8
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D7
    call RedTenthsDigit7
    jump Tenths_Digit_Done
G_10th_D7:
    call GrnTenthsDigit7
    jump Tenths_Digit_Done
Tenths_Digit8:
    move	ACC,   #0008h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit9
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D8
    call RedTenthsDigit8
    jump Tenths_Digit_Done
G_10th_D8:
    call GrnTenthsDigit8
    jump Tenths_Digit_Done
Tenths_Digit9:
    move	ACC,   #0009h		    
    sub A[10] ; ACC - A[10]
    jump NZ, Tenths_Digit?
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D9
    call RedTenthsDigit9
    jump Tenths_Digit_Done
G_10th_D9:
    call GrnTenthsDigit9
    jump Tenths_Digit_Done
Tenths_Digit?:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_D?
    call RedTenthsDigit?
    jump Tenths_Digit_Done
G_10th_D?:
    call GrnTenthsDigit?
Tenths_Digit_Done:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_10th_DOT
    call RedTenthsDigitGrnDecimalPoint
    jump Tenths_Decimal_Done
G_10th_DOT:
    call GrnTenthsDigitRedDecimalPoint
Tenths_Decimal_Done:


Hundreths_Digit0:
    move	ACC,   #0000h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit1
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D0
    call RedHundrethsDigit0
    jump Hundreths_Digit_Done
G_100th_D0:
    call GrnHundrethsDigit0
    jump Hundreths_Digit_Done
Hundreths_Digit1:
    move	ACC,   #0001h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit2
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D1
    call RedHundrethsDigit1
    jump Hundreths_Digit_Done
G_100th_D1:
    call GrnHundrethsDigit1
    jump Hundreths_Digit_Done
Hundreths_Digit2:
    move	ACC,   #0002h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit3
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D2
    call RedHundrethsDigit2
    jump Hundreths_Digit_Done
G_100th_D2:
    call GrnHundrethsDigit2
    jump Hundreths_Digit_Done
Hundreths_Digit3:
    move	ACC,   #0003h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit4
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D3
    call RedHundrethsDigit3
    jump Hundreths_Digit_Done
G_100th_D3:
    call GrnHundrethsDigit3
    jump Hundreths_Digit_Done
Hundreths_Digit4:
    move	ACC,   #0004h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit5
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D4
    call RedHundrethsDigit4
    jump Hundreths_Digit_Done
G_100th_D4:
    call GrnHundrethsDigit4
    jump Hundreths_Digit_Done
Hundreths_Digit5:
    move	ACC,   #0005h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit6
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D5
    call RedHundrethsDigit5
    jump Hundreths_Digit_Done
G_100th_D5:
    call GrnHundrethsDigit5
    jump Hundreths_Digit_Done
Hundreths_Digit6:
    move	ACC,   #0006h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit7
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D6
    call RedHundrethsDigit6
    jump Hundreths_Digit_Done
G_100th_D6:
    call GrnHundrethsDigit6
    jump Hundreths_Digit_Done
Hundreths_Digit7:
    move	ACC,   #0007h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit8
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D7
    call RedHundrethsDigit7
    jump Hundreths_Digit_Done
G_100th_D7:
    call GrnHundrethsDigit7
    jump Hundreths_Digit_Done
Hundreths_Digit8:
    move	ACC,   #0008h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit9
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D8
    call RedHundrethsDigit8
    jump Hundreths_Digit_Done
G_100th_D8:
    call GrnHundrethsDigit8
    jump Hundreths_Digit_Done
Hundreths_Digit9:
    move	ACC,   #0009h		    
    sub A[11] ; ACC - A[11]
    jump NZ, Hundreths_Digit?
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D9
    call RedHundrethsDigit9
    jump Hundreths_Digit_Done
G_100th_D9:
    call GrnHundrethsDigit9
    jump Hundreths_Digit_Done
Hundreths_Digit?:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_D?
    call RedHundrethsDigit?
    jump Hundreths_Digit_Done
G_100th_D?:
    call GrnHundrethsDigit?
Hundreths_Digit_Done:
    move	ACC,   #0000h		    
    sub A[6] ; ACC - A[6]    
    jump NZ, G_100th_DOT
    call RedHundrethsDigitGrnDecimalPoint
    jump Hundreths_Decimal_Done
G_100th_DOT:
    call GrnHundrethsDigitRedDecimalPoint
Hundreths_Decimal_Done:

;******************************************
; RX_Loop Forever
;******************************************
	jump RX_Loop
;******************************************

;*******************************************************************************
;* Function:  SPI_Conf_00
;*
;* Sets the SPI for:
;* 1)SPI Master Mode
;* 2)8-bit Transfers
;* 3)CPOL CPHA = 0,0
;* 4) SCLK Frequency 2.1MHz
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC, A[0], A[1], A[2], A[3], PSF
;*
;*******************************************************************************
SPI_Conf_00:

    move    A[0], #8000h		; System clock is 12288000 Hz
    move    A[1], #00BBh
    move    A[2], #0B20h		; Desired baud rate is 2100000 Hz
    move    A[3], #0020h
    call    spi_setbaudrate

    move    C, #SPI_IDLE_LOW
    call    spi_setclockpolarity
    move    C, #SPI_ACTIVE_EDGE
    call    spi_setclockphase
    move    C, #SPI_LENGTH_8
    call    spi_setcharacterlength
    move    C, #SPI_MASTER_MODE
    call    spi_setmode

    ; Enable SPI
    move    C, #1
    call    spi_enable
    ret

;*******************************************************************************
;*
;* Function:    Delay_2_and_a_half_ms (16MHz Clock)
;*
;* Description: Performs a pause
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
Delay_2_and_a_half_ms:
   move    LC[0], #9C40h    ;T => Decimal = 40,000
   djnz    LC[0], $
   ret 
  
;********************************************************************
;*
;* Function:    Delay_50ms (16MHz Clock)
;*
;* Description: Performs a 50ms Delay
;*
;* Input:       None
;*
;* Output:      None
;*
;* Destroys:    LC[0]
;*
;********************************************************************
Delay_50ms:
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    call Delay_2_and_a_half_ms
    ret

end
